import { Construct } from "constructs";
import { IActiveMqBroker } from "./activemq-broker";
import { ActiveMqBrokerDeploymentBase, ActiveMqBrokerDeploymentProps } from "./activemq-broker-deployment";
import { ActiveMqBrokerEndpoints } from "./activemq-broker-endpoints";
import { StorageType } from "../storage-type";
export interface ActiveMqBrokerInstanceProps extends ActiveMqBrokerDeploymentProps {
    /**
     * Sets the storage type of the Amazon MQ for ActiveMQ broker.
     * @default - undefined; EFS will be used.
     */
    readonly storageType?: StorageType;
}
/**
 * A representation of a single-instance broker comprised of one broker in one Availability Zone.
 *
 * Additional optimizations:
 * - When subnet selection returns more then 1 subnets. A first one is picked. Warning is annotated
 *
 *
 * see: https://docs.aws.amazon.com/amazon-mq/latest/developer-guide/single-broker-deployment.html
 */
export declare class ActiveMqBrokerInstance extends ActiveMqBrokerDeploymentBase implements IActiveMqBroker {
    /**
     * Gets the IP address of the ENI of the Amazon MQ for ActiveMQ broker.
     *
     * @attribute
     */
    readonly ipAddress: string;
    /**
     * Gets the available endpoints of the Amazon MQ for ActiveMQ broker.
     */
    readonly endpoints: ActiveMqBrokerEndpoints;
    constructor(scope: Construct, id: string, props: ActiveMqBrokerInstanceProps);
}
