import { Construct } from "constructs";
import { IActiveMqBroker } from "./activemq-broker";
import { ActiveMqBrokerDeploymentBase, ActiveMqBrokerDeploymentProps } from "./activemq-broker-deployment";
export interface ActiveMqBrokerRedundantPairProps extends ActiveMqBrokerDeploymentProps {
}
/**
 * A representation of an active/standby broker that is comprised of two brokers in two different Availability Zones.
 *
 * Additional optimizations:
 * - When subnet selection returns more then 2 subnets. Construct picks first two that do belong to different AZ. Warning is annotated. If subnet selection does not meet AZ criteria an error is thrown.
 *
 *
 * see: https://docs.aws.amazon.com/amazon-mq/latest/developer-guide/active-standby-broker-deployment.html
 */
export declare class ActiveMqBrokerRedundantPair extends ActiveMqBrokerDeploymentBase {
    /**
     * The first broker of the redundant pair for the deployment.
     */
    readonly first: IActiveMqBroker;
    /**
     * The second broker of the redundant pair for the deployment.
     */
    readonly second: IActiveMqBroker;
    constructor(scope: Construct, id: string, props: ActiveMqBrokerRedundantPairProps);
}
